utils::globalVariables(c(
  "equations_mets", 
  "Study",
  "sed_cutpoints",
  "mvpa_cutpoints",
  "sed_cutpoint_chosen",
  "mpa_cutpoint_chosen",
  "vpa_cutpoint_chosen",
  "axis_sed_chosen_name", 
  "axis_mvpa_chosen_name",
  "wear_time",
  "validity",
  "total_counts_axis1",
  "total_counts_vm",
  "total_steps",
  "minutes_SED",
  "minutes_LPA",
  "minutes_MPA",
  "minutes_VPA",
  "minutes_MVPA",
  "percent_SED",
  "percent_LPA",
  "percent_MPA",
  "percent_VPA",
  "percent_MVPA",
  "mets_hours_mvpa",
  "ratio_mvpa_sed",
  "pal", 
  "SED",
  "LPA",
  "MPA",
  "VPA",
  "METS",
  "wearing",
  "axis1",
  "axis2",
  "axis3",
  "timestamp",
  "time",
  "everything",
  "wearing",
  "wearing_count",
  "vm",
  "steps",
  "kcal",
  "max_steps_60min",
  "max_steps_30min",
  "max_steps_20min",
  "max_steps_5min",
  "max_steps_1min",
  "peak_steps_60min",
  "peak_steps_30min",
  "peak_steps_20min",
  "peak_steps_5min",
  "peak_steps_1min",
  "accum_steps_60min",
  "accum_steps_30min",
  "accum_steps_20min",
  "accum_steps_5min",
  "accum_steps_1min",
  "head",
  "col_time_stamp",
  "wear_time_revised",
  "total_kcal",
  "axis1_per_min",
  "vm_per_min",
  "median",
  "end",
  "intensity_category",
  "label",
  "line",
  "loess",
  "loess.control",
  "low",
  "mid",
  "pred",
  "start",
  "up",
  "value",
  "variable",
  "x",
  "xend",
  "xmax",
  "xmin",
  "y",
  "yend",
  "Date",
  "TimeStamp",
  "Selected_Day_ID",
  "Steps_score",
  "VMU_score",
  "Validity",
  "Day",
  "Jour",
  "score_type",
  "Item",
  "difficulty_score_raw",
  "difficulty_score_raw_diff",
  "difficulty_score_rasch",
  "amount_score_raw",
  "amount_score_raw_quant",
  "amount_score_rasch",
  "total_score_raw",
  "total_score_rasch",
  "n_breaks",
  "dur_cat",
  "bout",
  "duration",
  "cum_frac_time",
  "cum_frac_bout",
  "nls",
  "new_bout",
  "new_intensity_category",
  "valid_days",
  "ig",
  "M1/3",
  "M120",
  "M60",
  "M30",
  "M15",
  "M5",
  "metric",
  "val",
  "cutpoint",
  "x_lab",
  "y_lab",
  ":=",
  "value_maj",
  "Metric",
  "Indicateur",
  "bin_start",
  "bin_mid",
  "bin_label",
  "lm",
  "days",
  "."
  ))
